module PowerNetworkMatrices

export PTDF
export VirtualPTDF
export IncidenceMatrix
export BA_Matrix
export Ybus
export LODF
export Adjacency

export dfs_connectivity
export find_connected_components
export validate_connectivity

using DocStringExtensions
import InfrastructureSystems
import PowerSystems
import PowerSystems: BusTypes

const IS = InfrastructureSystems
const PSY = PowerSystems

import SparseArrays
import KLU: klu
import KLU
import LinearAlgebra: LAPACK.getri!, LAPACK.getrf!, BLAS.gemm, BLAS.set_num_threads
import LinearAlgebra: ldiv!, mul!, I
import LinearAlgebra
import Pardiso

@template (FUNCTIONS, METHODS) = """
                                 $(TYPEDSIGNATURES)
                                 $(DOCSTRING)
                                 """

# network calculations
include("PowerNetworkMatrix.jl")
include("BA_ABA_matrices.jl")
include("incedence_matrix.jl")
include("common.jl")
include("definitions.jl")
include("ptdf_calculations.jl")
include("ybus_calculations.jl")
include("lodf_calculations.jl")
include("virtual_ptdf_calculations.jl")

end
